# Copy of aiopath python v3.9

[Original Source Code](https://github.com/alexdelorenzo/aiopath/tree/Python-3.9)

Due to breaking changes in 3.10, this dir keeps the same implementation to maintain compatibility.

